Struct ZxdgOutputManagerV1
pub struct ZxdgOutputManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
manage xdg_output objects
A global factory interface for xdg_output objects.
This interface has no events.
Implementations
impl ZxdgOutputManagerV1
impl ZxdgOutputManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the xdg_output_manager object
Using this request a client can tell the server that it is not going to use the xdg_output_manager object anymore.
Any objects already created through this instance are not affected.
pub fn get_xdg_output<U, D>(
&self,
output: &WlOutput,
qh: &QueueHandle<D>,
udata: U,
) -> ZxdgOutputV1
pub fn get_xdg_output<U, D>( &self, output: &WlOutput, qh: &QueueHandle<D>, udata: U, ) -> ZxdgOutputV1
create an xdg output from a wl_output
This creates a new xdg_output object for the given wl_output.